@@ -30,6 +30,7 @@
 #'@param po.text.fill The background of the threshold point text.
 #'@param liftpec Threshold point left displacement.
 #'@param rightpec Threshold point right displacement.
+#'@param legend.position Set the position of the legend.
 #'@importFrom "stats" "median"
 #'
 #'
@@ -47,7 +48,8 @@ scidca.coxph<-function(fit,newdata=NULL,timepoint='median',cmprsk=FALSE,modelnam
                        irrellabel="Nomogram irrelevant",text.size=4.5,text.col="green",colbar=TRUE,
                        threshold.text=FALSE,threshold.line=FALSE,nudge_x = 0,nudge_y = 0,
                        threshold.linetype=2,threshold.linewidth = 1.2,threshold.linecol="black",
-                       po.text.size=4,po.text.col="black",po.text.fill="white",liftpec=NULL,rightpec=NULL) {
+                       po.text.size=4,po.text.col="black",po.text.fill="white",liftpec=NULL,rightpec=NULL,
+                       legend.position = c(0.85,0.75)) {
   if (missing(fit)) stop("fit is missing .")
   fit<-fit;
   if (is.null(modelnames)) {modelnames<-"model"
@@ -71,17 +73,17 @@ scidca.coxph<-function(fit,newdata=NULL,timepoint='median',cmprsk=FALSE,modelnam
   }
   if (!is.null(newdata)) {
     net<-stdca(data=newdata, outcome=modely[2], ttoutcome=modely[1], timepoint=timepo1, predictors="prob1", probability=FALSE,
-               graph=FALSE)
+               graph=F)
   } else {
     net<-stdca(data=data, outcome=modely[2], ttoutcome=modely[1], timepoint=timepo1, predictors="prob1", probability=FALSE,
-               graph=FALSE)
+               graph=F)
   }
   ########
   p<-getplot(net,pyh=pyh,relcol=relcol,irrelcol=irrelcol,relabel=relabel,modelnames=modelnames,merge=merge,y.min=y.min,xstop=xstop,y.max=y.max,
              irrellabel=irrellabel,text.size=text.size,text.col=text.col,colbar=colbar,
              threshold.text=threshold.text,threshold.line=threshold.line,nudge_x = nudge_x,nudge_y = nudge_y,
              threshold.linetype=threshold.linetype,threshold.linewidth = threshold.linewidth,threshold.linecol=threshold.linecol,
-             po.text.size=po.text.size,po.text.col=po.text.col,po.text.fill=po.text.fill,liftpec=liftpec,rightpec=rightpec)
+             po.text.size=po.text.size,po.text.col=po.text.col,po.text.fill=po.text.fill,liftpec=liftpec,rightpec=rightpec,
+             legend.position)
   p
 }
-
